package com.ruoyi.project.production.service.impl;

import java.util.List;
import com.ruoyi.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.project.production.mapper.TMonthlyQualityReportS3009Mapper;
import com.ruoyi.project.production.domain.TMonthlyQualityReportS3009;
import com.ruoyi.project.production.service.ITMonthlyQualityReportS3009Service;

/**
 * 质量月报S3009Service业务层处理
 *
 * @author ruoyi
 * @date 2023-10-27
 */
@Service
public class TMonthlyQualityReportS3009ServiceImpl implements ITMonthlyQualityReportS3009Service
{
    @Autowired
    private TMonthlyQualityReportS3009Mapper tMonthlyQualityReportS3009Mapper;

    /**
     * 查询质量月报S3009
     *
     * @param id 质量月报S3009ID
     * @return 质量月报S3009
     */
    @Override
    public TMonthlyQualityReportS3009 selectTMonthlyQualityReportS3009ById(Long id)
    {
        return tMonthlyQualityReportS3009Mapper.selectTMonthlyQualityReportS3009ById(id);
    }

    /**
     * 查询质量月报S3009列表
     *
     * @param tMonthlyQualityReportS3009 质量月报S3009
     * @return 质量月报S3009
     */
    @Override
    public List<TMonthlyQualityReportS3009> selectTMonthlyQualityReportS3009List(TMonthlyQualityReportS3009 tMonthlyQualityReportS3009)
    {
        return tMonthlyQualityReportS3009Mapper.selectTMonthlyQualityReportS3009List(tMonthlyQualityReportS3009);
    }

    /**
     * 新增质量月报S3009
     *
     * @param tMonthlyQualityReportS3009 质量月报S3009
     * @return 结果
     */
    @Override
    public int insertTMonthlyQualityReportS3009(TMonthlyQualityReportS3009 tMonthlyQualityReportS3009)
    {
        tMonthlyQualityReportS3009.setCreateTime(DateUtils.getNowDate());
        return tMonthlyQualityReportS3009Mapper.insertTMonthlyQualityReportS3009(tMonthlyQualityReportS3009);
    }

    /**
     * 修改质量月报S3009
     *
     * @param tMonthlyQualityReportS3009 质量月报S3009
     * @return 结果
     */
    @Override
    public int updateTMonthlyQualityReportS3009(TMonthlyQualityReportS3009 tMonthlyQualityReportS3009)
    {
        tMonthlyQualityReportS3009.setUpdateTime(DateUtils.getNowDate());
        return tMonthlyQualityReportS3009Mapper.updateTMonthlyQualityReportS3009(tMonthlyQualityReportS3009);
    }

    /**
     * 批量删除质量月报S3009
     *
     * @param ids 需要删除的质量月报S3009ID
     * @return 结果
     */
    @Override
    public int deleteTMonthlyQualityReportS3009ByIds(Long[] ids)
    {
        return tMonthlyQualityReportS3009Mapper.deleteTMonthlyQualityReportS3009ByIds(ids);
    }

    /**
     * 删除质量月报S3009信息
     *
     * @param id 质量月报S3009ID
     * @return 结果
     */
    @Override
    public int deleteTMonthlyQualityReportS3009ById(Long id)
    {
        return tMonthlyQualityReportS3009Mapper.deleteTMonthlyQualityReportS3009ById(id);
    }
}
