package com.ruoyi.project.production.controller;

import java.util.Date;
import java.util.List;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.framework.aspectj.lang.annotation.Log;
import com.ruoyi.framework.aspectj.lang.enums.BusinessType;
import com.ruoyi.project.production.domain.TMonthlyQualityReportS3009;
import com.ruoyi.project.production.service.ITMonthlyQualityReportS3009Service;
import com.ruoyi.framework.web.controller.BaseController;
import com.ruoyi.framework.web.domain.AjaxResult;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.framework.web.page.TableDataInfo;

/**
 * 质量月报S3009Controller
 *
 * @author ruoyi
 * @date 2023-10-27
 */
@RestController
@RequestMapping("/production/s3009")
public class TMonthlyQualityReportS3009Controller extends BaseController
{
    @Autowired
    private ITMonthlyQualityReportS3009Service tMonthlyQualityReportS3009Service;

    /**
     * 查询质量月报S3009列表
     */
    @PreAuthorize("@ss.hasPermi('production:quality:list')")
    @GetMapping("/list")
    public AjaxResult list(TMonthlyQualityReportS3009 tMonthlyQualityReportS3009)
    {
        Date endDate = tMonthlyQualityReportS3009.getEndDate();
        endDate.setHours(23);
        endDate.setMinutes(59);
        endDate.setSeconds(59);
        tMonthlyQualityReportS3009.setEndDate(endDate);
        return AjaxResult.success(tMonthlyQualityReportS3009Service.selectTMonthlyQualityReportS3009List(tMonthlyQualityReportS3009));
    }

    /**
     * 导出质量月报S3009列表
     */
    @PreAuthorize("@ss.hasPermi('production:quality:export')")
    @Log(title = "质量月报S3009", businessType = BusinessType.EXPORT)
    @GetMapping("/export")
    public AjaxResult export(TMonthlyQualityReportS3009 tMonthlyQualityReportS3009)
    {
        List<TMonthlyQualityReportS3009> list = tMonthlyQualityReportS3009Service.selectTMonthlyQualityReportS3009List(tMonthlyQualityReportS3009);
        ExcelUtil<TMonthlyQualityReportS3009> util = new ExcelUtil<TMonthlyQualityReportS3009>(TMonthlyQualityReportS3009.class);
        return util.exportExcel(list, "quality");
    }

    /**
     * 获取质量月报S3009详细信息
     */
    @PreAuthorize("@ss.hasPermi('production:quality:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return AjaxResult.success(tMonthlyQualityReportS3009Service.selectTMonthlyQualityReportS3009ById(id));
    }

    /**
     * 新增质量月报S3009
     */
    @PreAuthorize("@ss.hasPermi('production:quality:add')")
    @Log(title = "质量月报S3009", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TMonthlyQualityReportS3009 tMonthlyQualityReportS3009)
    {
        return toAjax(tMonthlyQualityReportS3009Service.insertTMonthlyQualityReportS3009(tMonthlyQualityReportS3009));
    }

    /**
     * 修改质量月报S3009
     */
    @PreAuthorize("@ss.hasPermi('production:quality:edit')")
    @Log(title = "质量月报S3009", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TMonthlyQualityReportS3009 tMonthlyQualityReportS3009)
    {
        return toAjax(tMonthlyQualityReportS3009Service.updateTMonthlyQualityReportS3009(tMonthlyQualityReportS3009));
    }

    /**
     * 删除质量月报S3009
     */
    @PreAuthorize("@ss.hasPermi('production:quality:remove')")
    @Log(title = "质量月报S3009", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(tMonthlyQualityReportS3009Service.deleteTMonthlyQualityReportS3009ByIds(ids));
    }
}
